aboutsummaryrefslogtreecommitdiffstats
path: root/prototypes/workbench/web
diff options
context:
space:
mode:
authoreunhhu <[email protected]>2026-10-09 14:32:32 +0100
committereunhhu <[email protected]>2026-10-09 14:32:32 +0100
commitaa4edf2e592e96daa4475fbf6756b8630bb7e7c5 (patch)
tree9f7edc2913919013021d3ace5b29365c7122f899 /prototypes/workbench/web
parent82b99bfaa673265778df511b36ab22f0563049c0 (diff)
downloadpure-aa4edf2e592e96daa4475fbf6756b8630bb7e7c5.tar.gz
pure-aa4edf2e592e96daa4475fbf6756b8630bb7e7c5.zip
Batch executor, stage 5 of design 025: decide finds a kept round's bit once (an add of the key it asked, as a filter's is, takes the place found) and clears only the words of the bits it set (their places kept as it sets them): BFS 0.4% fewer instructions; seeds 1 2 3 5 23 (default and PURE_SELECT=all), the fixed sources (GRAPH's exists, memory and work faults where they were) and the unit tests pass
Diffstat (limited to 'prototypes/workbench/web')
0 files changed, 0 insertions, 0 deletions